First version of Acuration's LLM library

Try it out
```
pip install llm-acuration
```

```
from llm_acuration.hello import hello
hello()
```
Prints "Hello, Acuration World!"

You can use help() on functions to know more about them

0.0.4
- added requirements.txt file

0.0.5
- just testing out how to automatically install dependencies